@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -188,7 +188,12 @@ public final class SpamAssassinSpamHandler extends SpamHandler {
         ConfigView view = factory.getView(session.getUserId(), session.getContextId());
 
         ComposedConfigProperty<V> property = view.property(propertyName, clazz);
-        return (null != property && property.isDefined()) ? property.get() : defaultValue;
+        if (null == property) {
+            return defaultValue;
+        }
+
+        V value = property.get();
+        return value == null ? defaultValue : value;
     }
 
     @Override
@@ -302,7 +307,7 @@ public final class SpamAssassinSpamHandler extends SpamHandler {
                     if (content instanceof MailMessage) {
                         tmp = (MailMessage) content;
                     } else if (content instanceof MimeMessage) {
-                        tmp = MimeMessageConverter.convertMessage((MimeMessage) content, new DefaultConverterConfig(mailAccess.getMailConfig(), false, false));
+                        tmp = MimeMessageConverter.convertMessage((MimeMessage) content, new DefaultConverterConfig(mailAccess.getMailConfig(), false));
                     } else if (content instanceof InputStream) {
                         try {
                             tmp = MimeMessageConverter.convertMessage(new MimeMessage(MimeDefaultSession.getDefaultSession(), (InputStream) content), new DefaultConverterConfig(mailAccess.getMailConfig()));
